==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/RuntimeSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuntimeSpecBuilder extends RuntimeSpecFluentImpl<RuntimeSpecBuilder> implements VisitableBuilder<RuntimeSpec,RuntimeSpecBuilder> {

    RuntimeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public RuntimeSpecBuilder() {
        this(true);
    }

    public RuntimeSpecBuilder(Boolean validationEnabled) {
        this(new RuntimeSpec(), validationEnabled);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RuntimeSpec(), validationEnabled);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,RuntimeSpec instance) {
        this(fluent, instance, true);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,RuntimeSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApplicationClass(instance.getApplicationClass()); 
        fluent.withCapabilities(instance.getCapabilities()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withProvider(instance.getProvider()); 
        fluent.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuntimeSpecBuilder(RuntimeSpec instance) {
        this(instance,true);
    }

    public RuntimeSpecBuilder(RuntimeSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApplicationClass(instance.getApplicationClass()); 
        this.withCapabilities(instance.getCapabilities()); 
        this.withDependencies(instance.getDependencies()); 
        this.withMetadata(instance.getMetadata()); 
        this.withProvider(instance.getProvider()); 
        this.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableRuntimeSpec build() {
        EditableRuntimeSpec buildable = new EditableRuntimeSpec(fluent.getApplicationClass(),fluent.getCapabilities(),fluent.getDependencies(),fluent.getMetadata(),fluent.getProvider(),fluent.getVersion());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuntimeSpecBuilder that = (RuntimeSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/RuntimeSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuntimeSpecBuilder extends RuntimeSpecFluentImpl<RuntimeSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<RuntimeSpec,RuntimeSpecBuilder> {

    RuntimeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public RuntimeSpecBuilder() {
        this(true);
    }

    public RuntimeSpecBuilder(Boolean validationEnabled) {
        this(new RuntimeSpec(), validationEnabled);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RuntimeSpec(), validationEnabled);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,RuntimeSpec instance) {
        this(fluent, instance, true);
    }

    public RuntimeSpecBuilder(RuntimeSpecFluent<?> fluent,RuntimeSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApplicationClass(instance.getApplicationClass()); 
        fluent.withCapabilities(instance.getCapabilities()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withProvider(instance.getProvider()); 
        fluent.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuntimeSpecBuilder(RuntimeSpec instance) {
        this(instance,true);
    }

    public RuntimeSpecBuilder(RuntimeSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApplicationClass(instance.getApplicationClass()); 
        this.withCapabilities(instance.getCapabilities()); 
        this.withDependencies(instance.getDependencies()); 
        this.withMetadata(instance.getMetadata()); 
        this.withProvider(instance.getProvider()); 
        this.withVersion(instance.getVersion()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableRuntimeSpec build() {
        EditableRuntimeSpec buildable = new EditableRuntimeSpec(fluent.getApplicationClass(),fluent.getCapabilities(),fluent.getDependencies(),fluent.getMetadata(),fluent.getProvider(),fluent.getVersion());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuntimeSpecBuilder that = (RuntimeSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
